# Durak

A simple implementation of the Russian's [Durak](https://en.wikipedia.org/wiki/Durak) card game.

For example usage see [this](https://github.com/Artem-Goldenberg/Durak/blob/main/tests/Usage.ipynb)
